--
-- InteractiveButtons
-- Specialization for an interactive control button
--
-- @author  	Manuel Leithner (SFM-Modding)
-- @version 	v2.1
-- @date  		29/08/11
-- @history:	v1.0 - Initial version
--				v2.0 - converted to ls2011
--				v2.1 - improvements
--

InteractiveButtons = {};

function InteractiveButtons.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(InteractiveControl, specializations);
end;

function InteractiveButtons:load(xmlFile)

	local i=0;
	while true do
		local buttonName = string.format("vehicle.interactiveComponents.buttons.button(%d)", i);	
		if not hasXMLProperty(xmlFile, buttonName) then
			break;
		end;
		local name = Utils.getNoNil(g_i18n:getText(getXMLString(xmlFile, buttonName .. "#name")), "ERROR");
		local mark = Utils.indexToObject(self.components, getXMLString(xmlFile, buttonName .. "#mark"));
		local highlight = getChildAt(mark, 0);
		local size = Utils.getNoNil(getXMLFloat(xmlFile, buttonName .. "#size"), 0.1);
		local event = getXMLString(xmlFile, buttonName .. "#event");
		local onMessage = g_i18n:getText(Utils.getNoNil(getXMLString(xmlFile, buttonName .. "#onMessage"), "ic_button_on"));
		local offMessage =  g_i18n:getText(Utils.getNoNil(getXMLString(xmlFile, buttonName .. "#offMessage") , "ic_button_off"));
	
		local button = Button:new(nil, highlight, name, mark, size, event, self, onMessage, offMessage, self.infoBar);
		
		button.synch = Utils.getNoNil(getXMLBool(xmlFile, buttonName .. "#synch"), true);

		table.insert(self.interactiveObjects, button);
		i = i + 1;
	end;
end;

function InteractiveButtons:delete()
end;

function InteractiveButtons:mouseEvent(posX, posY, isDown, isUp, button)
end;

function InteractiveButtons:keyEvent(unicode, sym, modifier, isDown)
end;

function InteractiveButtons:update(dt)	
end;

function InteractiveButtons:draw()
end;



--
-- Button Class
-- Specifies an interactive Button
--
-- SFM-Modding
-- @author  Manuel Leithner
-- @date  29/08/11
--

Button = {};

function Button:new(node, highlight, name, mark, size, event, vehicle, onMessage, offMessage, infobar)

	local Button_mt = Class(Button, InteractiveComponentInterface);	
    local instance = InteractiveComponentInterface:new(node, highlight, name, mark, size, onMessage, offMessage, infobar, Button_mt);

	instance.vehicle = vehicle;
	instance.event = event;
	
	return instance;	
end;

function Button:delete()
	InteractiveComponentInterface.delete(self);
end;

function Button:mouseEvent(posX, posY, isDown, isUp, button)
	InteractiveComponentInterface.mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function Button:keyEvent(unicode, sym, modifier, isDown)
	InteractiveComponentInterface.keyEvent(self, unicode, sym, modifier, isDown);
end;

function Button:update(dt)
	if self.vehicle ~= nil then
		if self.event == "toggleHighbeam" then		
			self.isOpen = self.vehicle.B3["highbeam"][1].a;
		elseif self.event == "toggleWorklightsFront" then
			self.isOpen = self.vehicle.B3["work"][1].a;
		elseif self.event == "toggleWorklightsBackRight" then
			self.isOpen = self.vehicle.B3["work"][3].a;
		elseif self.event == "toggleWorklightsBackLeft" then
			self.isOpen = self.vehicle.B3["work"][2].a;
		elseif self.event == "toggleSprayer" then
			self.isOpen = self.vehicle.foldMoveDirection ~= 1;
		elseif self.event == "toggleBeaconLights" then
			self.isOpen = self.vehicle.beaconLightsActive;
		elseif self.event == "toggleLight" then
			self.isOpen = self.vehicle.lightsActive;
		elseif self.event == "toggleSprayerActivate" then
			self.isOpen = self.vehicle.isTurnedOn;
		elseif self.event == "toggleCareTyreIC" then
			self.isOpen = self.vehicle.wheelScaleState;
		elseif self.event == "toggleRueckcam" then
			self.isOpen = self.vehicle.rueckfahrcameraState;
		elseif (self.name == "togglemotorWork") then
            if self.vehicle.ignitionKey ~= self.isOpen then
                self.isOpen = self.vehicle.ignitionKey;
            end;	
		end;
	end;
	InteractiveComponentInterface.update(self, dt);
end;

function Button:draw()
	InteractiveComponentInterface.draw(self);
end;

function Button:doAction(noEventSend, forceAction)
	if self.vehicle ~= nil then
		if self.event == "toggleHighbeam" then	
			if forceAction == nil then
				local lt = self.vehicle.B3["highbeam"];	
				self.vehicle:setState("highbeam", not lt[1].a, true);
			else
				self.vehicle:setState("highbeam", forceAction, true);
			end;
		elseif self.event == "toggleWorklightsFront" then
			if forceAction == nil then
				local lt = self.vehicle.B3["work"];			
				self.vehicle:setState("work:1", not lt[1].a, true);
			else
				self.vehicle:setState("work:1", forceAction, true);
			end;
		elseif self.event == "toggleWorklightsBackRight" then
			if forceAction == nil then
				local lt = self.vehicle.B3["work"];			
				self.vehicle:setState("work:3", not lt[3].a, true);
			else
				self.vehicle:setState("work:3", forceAction, true);
			end;
		elseif self.event == "togglemotorWork" then
			if self.vehicle ~= nil then
				--self.isOpen = self.vehicle.ignitionKey; 
				if self.vehicle.isServer then
					if self.vehicle.ignitionKey then
						self.isOpen = false;               
						--self.vehicle.ignitionKey = false;
						--self.vehicle.allowedIgnition = true;
						self.vehicle:updateVehicleState(false);
					else
						self.isOpen = true;
						--self.vehicle.ignitionKey = true;
						--self.vehicle.allowedIgnition = true;
						self.vehicle:updateVehicleState(true);
					end;
				end;
			end;
		elseif self.event == "toggleWorklightsBackLeft" then
			if forceAction == nil then
				local lt = self.vehicle.B3["work"];			
				self.vehicle:setState("work:2", not lt[2].a, true);
			else
				self.vehicle:setState("work:2", forceAction, true);
			end;
		elseif self.event == "toggleBeaconLights" then
			if self.vehicle ~= nil then
				if self.vehicle.beaconLightsActive then
					self.vehicle:setBeaconLightsVisibility(false);
				else
					self.vehicle:setBeaconLightsVisibility(true);
				end;
			end;
		elseif self.event == "toggleLight" then
			if self.vehicle ~= nil then
				if self.vehicle.lightsActive then
					self.vehicle:setLightsVisibility(false);
				else
					self.vehicle:setLightsVisibility(true);
				end;
			end;
		elseif self.event == "toggleSprayerActivate" then
			if self.vehicle ~= nil then
				if self.vehicle.isTurnedOn then
					self.vehicle:setIsTurnedOn(false);
				else
					self.vehicle:setIsTurnedOn(true);
				end;
			end;
		elseif self.event == "toggleCareTyreIC" then
			if self.vehicle ~= nil then
				if self.vehicle.wheelScaleState then
					self.vehicle.wheelScaleState = false;
				else
					self.vehicle.wheelScaleState = true;
				end;
			end;
		elseif self.event == "toggleRueckcam" then
			if self.vehicle ~= nil then
				if self.vehicle.rueckfahrcameraState then
					self.vehicle.rueckfahrcameraState = false;
				else
					self.vehicle.rueckfahrcameraState = true;
				end;
			end;
		elseif self.event == "toggleSprayer" then
			if forceAction == nil then
				if self.vehicle.foldMoveDirection > 0.1 or (self.vehicle.foldMoveDirection == 0 and self.vehicle.foldAnimTime > 0.5) then
					self.vehicle:setFoldDirection(-1)
				else
					self.vehicle:setFoldDirection(1)
				end;
			end;
		end;	
	end;
end;

function Button:onEnter(dt)
	InteractiveComponentInterface.onEnter(self, dt);
end;

function Button:onExit(dt)
	InteractiveComponentInterface.onExit(self, dt);
end;

function Button:setActive()
	InteractiveComponentInterface.setActive(self, isActive);
end;

function Button:setVisible(isVisible)
	InteractiveComponentInterface.setVisible(self, isVisible);
end;